#include "musicTree.h"

MusicTree::MusicTree(Window* parent)
	: m_parent(parent)
{
	m_ListStore = ListStore::create(m_Data);
	append_column("Title", m_Data.m_Title);
	append_column("Artists", m_Data.m_Artists);

	set_model(m_ListStore);

	MenuItem* item = manage(new MenuItem("Player", true));
	m_Menu_Popup.append(*item);
	item->signal_activate().connect(sigc::mem_fun(this, &MusicTree::on_menu_player));

	item = manage(new MenuItem("Downloads", true));
	m_Menu_Popup.append(*item);
	item->signal_activate().connect(sigc::mem_fun(this, &MusicTree::on_menu_downloads));

	item = manage(new MenuItem("Downloads Window", true));
	m_Menu_Popup.append(*item);
	item->signal_activate().connect(sigc::mem_fun(this, &MusicTree::on_menu_downloads_window));

	m_http.signal_something().connect(sigc::mem_fun(this, &MusicTree::on_readFinish));
	m_Menu_Popup.accelerate(*this);
	m_Menu_Popup.show_all();
}

bool MusicTree::on_button_press_event(GdkEventButton *event)
{
	bool return_value = false;

	return_value = TreeView::on_button_press_event(event);

	if( (event->type == GDK_BUTTON_PRESS) && (event->button == 3) )
	{
		m_Menu_Popup.popup(event->button, event->time);
	}

	return return_value;
}

void MusicTree::append_row_data(string &musicID ,string &title, string &artists)
{
	TreeModel::Row row = *(m_ListStore->append());

	row[m_Data.m_Title] = title;
	row[m_Data.m_Artists] = artists;
	row[m_Data.m_MusicID] = musicID;
}

void MusicTree::clear()
{
	m_ListStore->clear();
}

void MusicTree::on_menu_player()
{

	//Down_Dialog dialog("", m_parent, "");
	//dialog.run();
}

void MusicTree::on_menu_downloads()
{
	string url;

	Glib::RefPtr<Gtk::TreeView::Selection> refSelection = get_selection();
	if(refSelection) {
		Gtk::TreeModel::iterator iter = refSelection->get_selected();
		if(iter) {
			Glib::ustring id = (*iter)[m_Data.m_MusicID];
			url = Glib::ustring::compose(SEARCH_URL, id);

			m_http.set_url(url);
			m_http.append_request_head("Connection", "close");
			m_http.get();
		}
	}
}


void MusicTree::on_readFinish(string data)
{
	if(!m_parent) {
		cout << "parent == 0" << endl;
		return;
	}
	if(data.empty()) {
		return;
	}
	m_http.get_Response_code();
		Down_Dialog dialog(data, m_parent, "Please enter the music quality");
//  dialog.set_secondary_text("And this is the secondary text that explains things.");

  dialog.run();
}

void MusicTree::set_parent_window(Window* parent)
{
	m_parent = parent;
}

void MusicTree::on_menu_downloads_window()
{
}
